Struct CachedRibbitClient

pub struct CachedRibbitClient { /* private fields */ }
A caching wrapper around RibbitClient for raw responses

Implementations

Source

impl CachedRibbitClient

pub async fn new(region: Region) -> Result<Self>

Create a new cached Ribbit client

pub async fn with_cache_dir(region: Region, cache_dir: PathBuf) -> Result<Self>

Create a new cached client with custom cache directory

pub fn set_caching_enabled(&mut self, enabled: bool)

Enable or disable caching

pub async fn request(&self, endpoint: &Endpoint) -> Result<Response>

Make a request with caching

This method caches the raw response and reconstructs the Response object when serving from cache.

pub async fn request_raw(&self, endpoint: &Endpoint) -> Result<Vec<u8>>

Make a raw request with caching

This is a convenience method that returns just the raw bytes.

pub async fn request_typed<T: TypedResponse>( &self, endpoint: &Endpoint, ) -> Result<T>

Request with automatic type parsing

This method caches the raw response and parses it into the appropriate typed structure. It’s a drop-in replacement for RibbitClient::request_typed.

pub async fn get_product_versions( &self, product: &str, ) -> Result<ProductVersionsResponse>

Request product versions with typed response

Convenience method with caching for requesting product version information.

pub async fn get_product_cdns( &self, product: &str, ) -> Result<ProductCdnsResponse>

Request product CDNs with typed response

Convenience method with caching for requesting CDN server information.

pub async fn get_product_bgdl( &self, product: &str, ) -> Result<ProductBgdlResponse>

Request product background download config with typed response

Convenience method with caching for requesting background download configuration.

pub async fn get_summary(&self) -> Result<SummaryResponse>

Request summary of all products with typed response

Convenience method with caching for requesting the summary of all available products.

pub fn inner(&self) -> &RibbitClient

Get the underlying RibbitClient

pub fn inner_mut(&mut self) -> &mut RibbitClient

Get mutable access to the underlying RibbitClient

pub async fn clear_cache(&self) -> Result<()>

Clear all cached responses

pub async fn clear_expired(&self) -> Result<()>

Clear expired cache entries